@@ -136,7 +136,7 @@ so slow that gsutil disables downloads of composite objects.""".split(
 def _start_procs(src_dst_pairs: list) -> Generator[subprocess.Popen, None, None]:
     """
     Starts multiple "gsutil cp" subprocesses.
-    
+
     src_dst_pairs: a list of tuples (local file path, target GCS path)
 
     Yields subprocess.Popen objects
@@ -310,7 +310,9 @@ def _check_for_gs_files(
     # separate by bucket, to do single ls per bucket
     # then check in the return for all the files
     for bucket, gs_file_mapping in gs_uris_to_check.items():
-        sub = subprocess.run(["gsutil", "ls", "-r", bucket], capture_output=True)
+        sub = subprocess.run(
+            ["gsutil", "ls", "-r", f"gs://{bucket}"], capture_output=True
+        )
         if sub.returncode != 0:
             click.secho(
                 f"Error getting {bucket} to check files: {sub.stderr.decode('utf-8'), }",
@@ -357,8 +359,8 @@ def _compose_file_mapping(
     upload_info: api.UploadInfo, xlsx: str
 ) -> Tuple[Dict[str, str], List[str]]:
     """
-    Returns a list of (source_path, target uri) pairs for all 
-    the files from the upload info relative to the `work dir` 
+    Returns a list of (source_path, target uri) pairs for all
+    the files from the upload info relative to the `work dir`
     that is xlsx file locaction. If s source_path is a GCS uri,
     it will return it w/o change.
     """
@@ -376,7 +378,7 @@ def _compose_file_mapping(
             source_path = os.path.join(xlsx_dir, source_path)
 
             if not os.path.isfile(source_path):
-                if source_path in upload_info.optional_files:
+                if any(source_path.endswith(f) for f in upload_info.optional_files):
                     missing_optional_files.append(gcs_uri)
                     continue
                 else:
